//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/SampleDesigner/SampleView.h
//! @brief     Defines class SampleView.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_SAMPLEVIEW_H
#define BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_SAMPLEVIEW_H

#include <QWidget>

class Item3D;
class ProjectDocument;
class QMenu;
class RealspacePanel;
class SampleListing;

class SampleView : public QWidget {
    Q_OBJECT
public:
    SampleView(QWidget* parent, ProjectDocument* document);
    ~SampleView();

    void fillViewMenu(QMenu* menu);

private:
    void showEvent(QShowEvent*) override;

    void updateSingleSampleMode();

    //! Show the item in the real space view
    //!
    //! If the real space view is not visible at the moment, it will be shown.
    void onRequestViewInRealspace(Item3D* item);

    void onAboutToRemoveItem(Item3D* item);

    void onSingleSampleModeChanged(bool newState);

    void applySplitterPos();
    void saveSplitterPos();

    ProjectDocument* m_document = nullptr;
    RealspacePanel* m_realspacePanel = nullptr;
    SampleListing* m_listing = nullptr;
};

#endif // BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_SAMPLEVIEW_H
